@@ -5,6 +5,10 @@
    Provided under GPL version 2 or later.
 */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
 
 #include <unistd.h>
 
@@ -338,7 +342,7 @@ char *burn_util_thread_id(pid_t pid, pthread_t tid, char text[80])
 {
 	int i, l;
 
-	sprintf(text, "[%d,", getpid());
+	sprintf(text, "[%lu,", (unsigned long int) getpid());
 	l= strlen(text);
 	for(i= 0; i < sizeof(pthread_t) && 2 * i < 80 - l - 3; i++)
 		sprintf(text + l + 2 * i,
