@@ -5,6 +5,10 @@
    Provided under GPL version 2 or later.
 */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
 
 /* #include <m alloc.h>  ts A61013 : not in GNU/Linux man 3 malloc */
 
