@@ -5,9 +5,12 @@
    Provided under GPL version 2 or later.
 */
 
-
 /* scsi primary commands */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
 #include <unistd.h>
 #include <stdio.h>
 #include <sys/types.h>
@@ -246,7 +249,7 @@ void spc_inquiry(struct burn_drive *d)
 	memcpy(c.opcode, SPC_INQUIRY, sizeof(SPC_INQUIRY));
 	c.oplen = sizeof(SPC_INQUIRY);
 */
-	c.dxfer_len= (c.opcode[3] << 8) | c.opcode[4];
+	c.dxfer_len = (c.opcode[3] << 8) | c.opcode[4];
 	c.retry = 1;
 	c.page = &buf;
 	c.page->bytes = 0;
