@@ -10,6 +10,10 @@
    Provided under GPL version 2 or later.
 */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
 /* <<< A70929 : hardcoded CD-RW with fabricated -msinfo 
 #define Hardcoded_cd_rW 1
 #define Hardcoded_cd_rw_c1     12999
