@@ -340,6 +340,11 @@ struct isoburn_imgen_opts {
      */
     unsigned int file_md5 :2;
 
+    /* On overwriteable media or random access files do not write the first
+       session to LBA 32, but rather to LBA 0 directly.
+     */
+    unsigned int no_emul_toc :1;
+
     /* relaxed constraints */
 
     /*
