@@ -1,10 +1,10 @@
 
 /*
-  API definition of libisoburn.
+  Lower level API definition of libisoburn.
 
   Copyright 2007-2010 Vreixo Formoso Lopes <metalpain2002@yahoo.es>
                   and Thomas Schmitt <scdbackup@gmx.net>
-   Provided under GPL version 2 or later.
+  Provided under GPL version 2 or later.
 */
 
 /**                           Overview
@@ -18,6 +18,9 @@ The price for that is thorough specialization on data files in ISO-9660
 filesystem images. So libisoburn is not suitable for audio (CD-DA) or any
 other CD layout which does not entirely consist of ISO-9660 sessions.
 
+Note that there is a higher level of API: xorriso.h. One should not mix it
+with the API calls of libisoburn.h, libisofs.h, and libburn.h.
+
 
                           Connector functions
 
@@ -161,7 +164,7 @@ int isoburn_initialize(char msg[1024], int flag);
     major.minor.micro revision triple can be delivered by the library version
     which is performing this call.
     An application of libisoburn can easily memorize the version of the
-    libisofs.h header in its own code. Immediately after isoburn_initialize()
+    libisoburn.h header in its own code. Immediately after isoburn_initialize()
     it should simply do this check:
         if (! isoburn_is_compatible(isoburn_header_version_major,
                                     isoburn_header_version_minor,
@@ -224,8 +227,8 @@ void isoburn_version(int *major, int *minor, int *micro);
     @since 0.1.0
 */
 #define isoburn_libburn_req_major  0
-#define isoburn_libburn_req_minor  7
-#define isoburn_libburn_req_micro  8
+#define isoburn_libburn_req_minor  8
+#define isoburn_libburn_req_micro  2
 
 
 /** The minimum version of libisofs to be used with this version of libisoburn
@@ -261,7 +264,7 @@ int isoburn_libburn_req(int *major, int *minor, int *micro);
 */
 #define isoburn_header_version_major  0
 #define isoburn_header_version_minor  5
-#define isoburn_header_version_micro  6
+#define isoburn_header_version_micro  8
 /** Note:
     Above version numbers are also recorded in configure.ac because libtool
     wants them as parameters at build time.
@@ -942,6 +945,12 @@ int isoburn_igopt_get_level(struct isoburn_imgen_opts *o, int *level);
                  compare this with the MD5 of the actual copying. If they do
                  not match then issue MISHAP event.
                  See also libisofs.h  iso_write_opts_set_record_md5()
+           bit9= no_emul_toc
+                 @since 0.5.8
+                 On overwriteable media or random access files do not write
+                 the first session to LBA 32 and do not copy the first 64kB
+                 of the first session to LBA 0, but rather write the first
+                 session to LBA 0 directly.
     @return 1 success, <=0 failure
 */
 #define isoburn_igopt_rockridge         1
@@ -952,6 +961,7 @@ int isoburn_igopt_get_level(struct isoburn_imgen_opts *o, int *level);
 #define isoburn_igopt_session_md5      64
 #define isoburn_igopt_file_md5        128
 #define isoburn_igopt_file_stability  256
+#define isoburn_igopt_no_emul_toc     512
 int isoburn_igopt_set_extensions(struct isoburn_imgen_opts *o, int ext);
 int isoburn_igopt_get_extensions(struct isoburn_imgen_opts *o, int *ext);
 
