@@ -6,6 +6,11 @@
  * or later as published by the Free Software Foundation. 
  * See COPYING file for details.
  */
+
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
 #include <stdlib.h>
 #include <sys/types.h>
 #include <string.h>
@@ -153,6 +158,8 @@ const char *iso_error_to_msg(int errcode)
         return "Try to set the boot image of an already bootable image";
     case ISO_BOOT_IMAGE_NOT_VALID:
         return "Trying to use an invalid file as boot image";
+    case ISO_BOOT_IMAGE_OVERFLOW:
+        return "Too many boot images added";
     case ISO_FILE_ERROR:
         return "Error on file operation";
     case ISO_FILE_ALREADY_OPENED:
