@@ -9,6 +9,10 @@
  * See COPYING file for details.
  */
 
+#ifdef HAVE_CONFIG_H
+#include "../config.h"
+#endif
+
 #include "util.h"
 #include "libisofs.h"
 #include "messages.h"
