@@ -1,12 +1,29 @@
 
-/* Command line oriented batch and dialog tool which creates, loads,
-   manipulates and burns ISO 9660 filesystem images.
+/* xorriso - libisoburn higher level API which creates, loads, manipulates
+             and burns ISO 9660 filesystem images.
 
    Copyright 2007-2010 Thomas Schmitt, <scdbackup@gmx.net>
 
    Provided under GPL version 2 or later.
 
-   This file contains the public option interface of xorriso.
+   This file contains the public API of xorriso which covers all of its
+   operations.
+
+   An example of its usage is xorriso_main.c which checks version compatibility,
+   creates a xorriso object, initializes the libraries, and runs the command
+   interpreters of the API to constitute the command line oriented batch and
+   dialog tool xorriso.
+
+   Alternatively to command interpreters it is possible to run all options of
+   xorriso directly via the calls of the "Options API". 
+   The "Problem Status and Message API" shall then be used to obtain the
+   text output of the options.
+
+   Mandatory calls are:
+     Xorriso_new(), Xorriso_startup_libraries(), Xorriso_destroy()
+
+   There is a lower level of API which consists of libisofs.h, libburn.h and
+   libisoburn.h. One should not mix those calls with the ones of xorriso.h .
 */
 
 #ifndef Xorriso_includeD
@@ -16,20 +33,81 @@
 struct XorrisO; 
 
 
-#define Xorriso_program_versioN "0.5.4"
-#define Xorriso_program_patch_leveL ""
+
+/* Create GNU xorriso
+   under GPLv3+ derived from above GPLv2+.
+*/
+#define Xorriso_GNU_xorrisO yes
 
 
 /* --------------------- Fundamental Management ------------------- */
 
 
-/* Get the version text (e.g. "0.4.2") of the program code.
-   This may differ from Xorriso_program_versioN if xorriso is dynamically
-   linked to an application.
-   @param flag     unused yet, submit 0
-   @return         readonly character string
+/** These three release version numbers tell the revision of this header file
+    and of the API which it describes. They shall be memorized by applications
+    at build time.
+    @since 0.5.8
 */
-char *Xorriso__get_version_text(int flag);
+#define Xorriso_header_version_majoR  0
+#define Xorriso_header_version_minoR  5
+#define Xorriso_header_version_micrO  8
+
+
+/** Eventually something like ".pl01" to indicate a bug fix. Normally empty.
+    @since 0.5.8
+*/
+#define Xorriso_program_patch_leveL ""
+
+
+/** Obtain the three release version numbers of the library. These are the
+    numbers encountered by the application when linking with libisoburn,
+    i.e. possibly not before run time.
+    Better do not base the fundamental compatibility decision of an application
+    on these numbers. For a reliable check use Xorriso__is_compatible().
+    @since 0.5.8
+    @param major The maturity version (0 for now, as we are still learning)
+    @param minor The development goal version.
+    @param micro The development step version. This has an additional meaning:
+
+                 Pare numbers indicate a version with frozen API. I.e. you can
+                 rely on the same set of features to be present in all
+                 published releases with that major.minor.micro combination.
+                 Features of a pare release will stay available and ABI
+                 compatible as long as the SONAME of libisoburn stays "1".
+                 Currently there are no plans to ever change the SONAME.
+                  
+                 Odd numbers indicate that API upgrades are in progress.
+                 I.e. new features might be already present or they might
+                 be still missing. Newly introduced features may be changed
+                 incompatibly or even be revoked before release of a pare
+                 version.
+                 So micro revisions {1,3,5,7,9} should never be used for
+                 dynamic linking unless the proper library match can be
+                 guaranteed by external circumstances.
+
+    @return 1 success, <=0 might in future become an error indication
+*/
+void Xorriso__version(int *major, int *minor, int *micro);
+
+
+/** Check whether all features of header file xorriso.h from the given
+    major.minor.micro revision triple can be delivered by the library version
+    which is performing this call.
+        if (! Xorriso__is_compatible(Xorriso_header_version_majoR,
+                                     Xorriso_header_version_minoR,
+                                     Xorriso_header_version_micrO, 0))
+           ...refuse to start the program with this dynamic library version...
+    @since 0.5.8
+    @param major obtained at build time
+    @param minor obtained at build time
+    @param micro obtained at build time
+    @param flag Bitfield for control purposes. Unused yet. Submit 0.
+    @return 1= library can work for caller
+            0= library is not usable in some aspects. Caller must restrict
+               itself to an earlier API version or must not use this libray
+               at all.
+*/
+int Xorriso__is_compatible(int major, int minor, int micro, int flag);
 
 
 /* Get the patch level text (e.g. "" or ".pl01") of the program code.
@@ -74,8 +152,71 @@ int Xorriso__preset_signal_behavior(int behavior, int flag);
 int Xorriso_new(struct XorrisO ** xorriso, char *progname, int flag);
 
 
-/* Interpret certain commands which shall get into effect before the
-   libraries get initialized:
+/* Note: Between Xorriso_new() and the next call Xorriso_startup_libraries()
+         there may be called the special command interpreter
+         Xorriso_prescan_args().
+         The other command interpreters may be used only after
+         Xorriso_startup_libraries(). The same restriction applies to the
+         calls of the Options API further below.
+*/
+
+
+/* Mandatory call:
+   It has to be made before calling any function listed below this point.
+   Only exception is the special command interpreter Xorriso_prescan_args().
+
+   Make global library initializations.
+   This must be done with the first xorriso object that gets created and
+   with the first xorriso object that gets created after Xorriso_destroy(,1).
+   @param xorriso The context object.
+   @param flag    unused yet, submit 0
+   @return        <=0 error , >0 success
+*/ 
+int Xorriso_startup_libraries(struct XorrisO *xorriso, int flag);
+
+
+/* Note: After library startup, you may run Command Interpreters or call
+         functions from the Options API.
+
+         Wenn all desired activities are done, you may check whether there are
+         uncommited chages pending, compute an exit value, destroy the XorrisO
+         object, and exit your program.
+*/
+
+
+/* Inquire whether option -commit would make sense.
+   @param xorriso The context object to inquire.
+   @param flag    unused yet, submit 0
+   @return        0= -commit would have nothing to do
+                  1= a new image session would emerge at -commit
+*/
+int Xorriso_change_is_pending(struct XorrisO *xorriso, int flag);
+
+
+/* Compute the exit value from the recorded maximum event severity.
+   @param xorriso The context object to inquire.
+   @param flag    unused yet, submit 0
+   @return        The computed exit value
+*/
+int Xorriso_make_return_value(struct XorrisO *xorriso, int flag);
+
+
+/* Mandatory call:
+   Destroy xorriso object when it is no longer needed.
+   @param xorriso  The context object to destroy. *xorriso will become NULL.
+   @param flag     bit0= Perform global library shutdown.
+                         Use only with last xorriso object to be destroyed.
+   @return         <=0 error, >0 success
+*/
+int Xorriso_destroy(struct XorrisO **xorriso, int flag);
+
+
+/* --------------------- Command Interpreters ------------------- */
+
+
+/* This special interpreter is eventually called between Xorriso_new() and
+   Xorriso_startup_libraries(). It interprets certain commands which shall
+   get into effect before the libraries get initialized:
      -abort_on , -report_about , -return_with , -list_delimiter
    Some commands get executed only if they are the only command in argv:
      -prog_help , -help , -no_rc
@@ -98,19 +239,6 @@ int Xorriso_prescan_args(struct XorrisO *xorriso, int argc, char **argv,
                          int flag);
 
 
-/* Mandatory call:
-   It has to be made before calling any function listed below this point.
-
-   Make global library initializations.
-   This must be done with the first xorriso object that gets created and
-   with the first xorriso object that gets created after Xorriso_destroy(,1).
-   @param xorriso The context object.
-   @param flag    unused yet, submit 0
-   @return        <=0 error , >0 success
-*/ 
-int Xorriso_startup_libraries(struct XorrisO *xorriso, int flag);
-
-
 /* Read and interpret commands from eventual startup files as listed in
    man xorriso.
    @param xorriso The context object in which to perform the commands.
@@ -192,33 +320,6 @@ int Xorriso_execute_option(struct XorrisO *xorriso, char *line, int flag);
 int Xorriso_dialog(struct XorrisO *xorriso, int flag);
 
 
-/* Inquire whether option -commit would make sense.
-   @param xorriso The context object to inquire.
-   @param flag    unused yet, submit 0
-   @return        0= -commit would have nothing to do
-                  1= a new image session would emerge at -commit
-*/
-int Xorriso_change_is_pending(struct XorrisO *xorriso, int flag);
-
-
-/* Compute the exit value from the recorded maximum event severity.
-   @param xorriso The context object to inquire.
-   @param flag    unused yet, submit 0
-   @return        The computed exit value
-*/
-int Xorriso_make_return_value(struct XorrisO *xorriso, int flag);
-
-
-/* Mandatory call:
-   Destroy xorriso object when it is no longer needed.
-   @param xorriso  The context object to destroy. *xorriso will become NULL.
-   @param flag     bit0= Perform global library shutdown.
-                         Use only with last xorriso object to be destroyed.
-   @return         <=0 error, >0 success
-*/
-int Xorriso_destroy(struct XorrisO **xorriso, int flag);
-
-
 /* --------------------- Problem Status and Message API ------------------- */
 
 
@@ -424,6 +525,7 @@ struct Xorriso_lsT *Xorriso_lst_get_prev(struct Xorriso_lsT *entry, int flag);
 
 /** Destroy all list items which are directly or indirectly connected to
     the given link item.
+    All pointers obtained by Xorriso_lst_get_text() become invalid by this.
     Apply this to each of the two list handles obtained by 
     Xorriso_pull_outlists() when the lists are no longer needed.
     @param lstring  *lstring will be freed and set to NULL.
@@ -574,6 +676,9 @@ int Xorriso_option_chowni(struct XorrisO *xorriso, char *uid,
 /* Option -close "on"|"off" */
 int Xorriso_option_close(struct XorrisO *xorriso, char *mode, int flag);
 
+/* Option -close_filter_list */
+int Xorriso_option_close_filter_list(struct XorrisO *xorriso, int flag);
+
 /* Option -commit */
 /* @param flag bit0= leave indrive and outdrive aquired as they were,
                      i.e. do not aquire outdrive as new in-out-drive
@@ -596,6 +701,9 @@ int Xorriso_option_commit_eject(struct XorrisO *xorriso, char *which, int flag);
 int Xorriso_option_compare(struct XorrisO *xorriso, char *disk_path,
                            char *iso_path, int flag);
 
+/* Option -compliance */
+int Xorriso_option_compliance(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Option -cpr alias -cpri */
 int Xorriso_option_cpri( struct XorrisO *xorriso, int argc, char **argv,
                          int *idx, int flag);
@@ -676,8 +784,10 @@ int Xorriso_option_extract(struct XorrisO *xorriso, char *disk_path,
 int Xorriso_option_extract_cut(struct XorrisO *xorriso, char *iso_rr_path,
                           char *start, char *count, char *disk_path, int flag);
 
-/* Option -follow */
-int Xorriso_option_follow(struct XorrisO *xorriso, char *mode, int flag);
+/* Option -file_size_limit */
+int Xorriso_option_file_size_limit(struct XorrisO *xorriso,
+                                   int argc, char **argv, int *idx, int flag);
+
 
 /* Option -find alias -findi, and -findx */
 /* @param flag bit0= -findx rather than -findi
@@ -687,6 +797,9 @@ int Xorriso_option_follow(struct XorrisO *xorriso, char *mode, int flag);
 int Xorriso_option_find(struct XorrisO *xorriso, int argc, char **argv,
                        int *idx, int flag);
 
+/* Option -follow */
+int Xorriso_option_follow(struct XorrisO *xorriso, char *mode, int flag);
+
 /* Option -fs */
 int Xorriso_option_fs(struct XorrisO *xorriso, char *size, int flag);
 
@@ -811,6 +924,9 @@ int Xorriso_option_not_leaf(struct XorrisO *xorriso, char *pattern, int flag);
 /* @param flag bit0= -quoted_not_list */
 int Xorriso_option_not_list(struct XorrisO *xorriso, char *adr, int flag);
 
+/* Option -not_mgt */
+int Xorriso_option_not_mgt(struct XorrisO *xorriso, char *setting, int flag);
+
 /* Option -not_paths */
 int Xorriso_option_not_paths(struct XorrisO *xorriso, int argc, char **argv,
                              int *idx, int flag);
@@ -860,6 +976,9 @@ int Xorriso_option_print_size(struct XorrisO *xorriso, int flag);
 /* Option -prog */
 int Xorriso_option_prog(struct XorrisO *xorriso, char *name, int flag);
 
+/* Option -prompt */
+int Xorriso_option_prompt(struct XorrisO *xorriso, char *text, int flag);
+
 /* Option -prog_help */
 int Xorriso_option_prog_help(struct XorrisO *xorriso, char *name, int flag);
 
