@@ -19,7 +19,7 @@
 */
 #define xorriso_libisoburn_req_major  0
 #define xorriso_libisoburn_req_minor  5
-#define xorriso_libisoburn_req_micro  6
+#define xorriso_libisoburn_req_micro  8
 
 
 struct SpotlisT;          /* List of intervals with different read qualities */
@@ -412,6 +412,15 @@ int Xorriso_setfattr(struct XorrisO *xorriso, void *in_node, char *path,
                      size_t num_attrs, char **names,
                      size_t *value_lengths, char **values, int flag);
 
+int Xorriso_perform_attr_from_list(struct XorrisO *xorriso, char *path,
+                      struct Xorriso_lsT *lst_start, int flag);
+
+int Xorriso_path_setfattr(struct XorrisO *xorriso, void *in_node, char *path,
+                       char *name, size_t value_length, char *value, int flag);
+
+int Xorriso_perform_acl_from_list(struct XorrisO *xorriso, char *file_path,
+                                  char *uid, char *gid, char *acl, int flag);
+
 int Xorriso_record_dev_inode(struct XorrisO *xorriso, char *disk_path,
                              dev_t dev, ino_t ino,
                              void *in_node, char *iso_path, int flag);
@@ -509,5 +518,18 @@ int Xorriso_boot_image_status(struct XorrisO *xorriso, char *filter, FILE *fp,
 #define Xorriso_IFBOOT S_IFMT
 
 
+int Exprtest_match(struct XorrisO *xorriso, struct ExprtesT *ftest,
+                   void *node_pt, char *name, char *path,
+                   struct stat *boss_stbuf, struct stat *stbuf, int flag);
+
+
+int Xorriso_toc_to_string(struct XorrisO *xorriso, char **toc_text, int flag);
+
+
+int Xorriso_reaquire_outdev(struct XorrisO *xorriso, int flag);
+
+int Xorriso_set_system_area_path(struct XorrisO *xorriso, char *path,
+                                 int flag);
+
 #endif /* Xorrisoburn_includeD */
 
